@@ -131,6 +131,16 @@ class Base:
                 state += str[i]
         return (elem, mass, state)
 
+    def _create_graphviz_string(self, str):
+        str_T = self._get_species_name_substrings(str)
+        elem = str_T[0]
+        if str_T[1]:
+            elem = str_T[0].title()
+        if str_T[2]:
+            return r"<<sup>%s</sup>%s<sub>%s</sub>>" % (str_T[1], elem, str_T[2])
+        else:
+            return r"<<sup>%s</sup>%s>" % (str_T[1], elem)
+
     def _create_latex_string(self, str):
         l_hash = {
             "gamma": "\\gamma",
@@ -156,6 +166,25 @@ class Base:
             else:
                 return r"^{%s}\rm{%s}" % (str_T[1], elem)
 
+    def get_graphviz_names(self, nuclides):
+        """Method to get graphviz strings of nuclides' names.
+
+        Args:
+            ``nuclides`` (:obj:`list`): A list of strings giving the nuclides.
+
+        Returns:
+            :obj:`dict`: A dictionary of graphviz strings.
+
+        """
+
+        graphviz_names = {}
+        for nuclide in nuclides:
+            graphviz_names[nuclide] = "{:s}".format(
+                self._create_graphviz_string(nuclide)
+            )
+
+        return graphviz_names
+
     def get_latex_names(self, nuclides):
         """Method to get latex strings of nuclides' names.
 
@@ -169,8 +198,7 @@ class Base:
 
         latex_names = {}
         for nuclide in nuclides:
-            name = r"$%s$" % (self._create_latex_string(nuclide))
-            latex_names[nuclide] = name
+            latex_names[nuclide] = "${:s}$".format(self._create_latex_string(nuclide))
 
         return latex_names
 
@@ -345,6 +373,13 @@ class Base:
 
         elem, mass, state = self._get_species_name_substrings(name)
 
+        if elem[0] == "n":
+            if not mass:
+                return (0, len(elem), state)
+            else:
+                if len(elem) == 1:
+                    return (7, int(mass), state)
+
         return (int(self._get_z_from_element_name(elem)), int(mass), state)
 
     def create_nuclide_name(self, z, a, state):
@@ -421,3 +456,30 @@ class Base:
 
         title_str = "time (s) = %8.2e" % (time)
         return title_str
+
+    def is_non_nuclide_reaction_element_string(self, name):
+        """Method to check if a string is that of a non-nuclide reaction element.
+
+        Args:
+            ``name`` (:obj:`str`): A string giving the possible non-nuclide
+            reaction element.
+
+        Returns:
+            :obj:`bool`: A boolean with value True if the string is that
+            of a non-nuclide reaction element and False if not.
+
+        """
+
+        non_nuclide_reaction_elements = [
+            "gamma",
+            "electron",
+            "positron",
+            "neutrino_e",
+            "anti-neutrino_e",
+            "neutrino_mu",
+            "anti-neutrino_mu",
+            "neutrino_tau",
+            "anti_neutrino_tau",
+        ]
+
+        return name in non_nuclide_reaction_elements
