@@ -13,13 +13,13 @@ with warnings.catch_warnings():
 class H5(wnb.Base):
     """A class for reading and plotting webnucleo HDF5 files.
 
-       Each instance corresponds to an hdf5 file.  Methods extract
-       data and plot data from the file.
+    Each instance corresponds to an hdf5 file.  Methods extract
+    data and plot data from the file.
 
-       Args:
-           ``file`` (:obj:`str`): The name of the hdf5 file.
+    Args:
+        ``file`` (:obj:`str`): The name of the hdf5 file.
 
-       """
+    """
 
     def __init__(self, file):
         self._h5file = h5py.File(file, "r")
@@ -151,12 +151,13 @@ class H5(wnb.Base):
     def get_group_mass_fractions(self, group):
         """Method to return mass fractions from a group in an hdf5 file.
 
-            Args:
-                ``group`` (:obj:`str`): The name of the group.
+        Args:
+            ``group`` (:obj:`str`): The name of the group.
 
-            Returns:
-                :obj:`h5py:Dataset`: A 2d hdf5 dataset.  The first index
-                indicates the zone and the second the species.
+        Returns:
+            A 2d hdf5
+            `dataset <https://docs.h5py.org/en/stable/high/dataset.html>`_.
+            The first index indicates the zone and the second the species.
 
         """
 
@@ -615,6 +616,95 @@ class H5(wnb.Base):
 
         self.show_or_close(plt, kwargs)
 
+    def plot_group_properties_vs_property(
+        self,
+        group,
+        prop,
+        props,
+        xfactor=1,
+        yfactor=None,
+        rcParams=None,
+        plotParams=None,
+        **kwargs
+    ):
+        """Method to plot group mass fractions vs. zone property.
+
+        Args:
+
+            ``group`` (:obj:`str`): A string giving the group.
+
+            ``prop`` (:obj:`str` or :obj:`tuple`): A string or tuple of
+            up to three strings giving the property (which will
+            serve as the plot abscissa).
+
+            ``props`` (:obj:`list`): A list of strings or tuples of
+            up to three strings giving the properties (which will
+            serve as the plot ordinates).
+
+            ``xfactor`` (:obj:`float`, optional): A float giving the scaling
+            for the abscissa values.  Defaults to 1.
+
+            ``yfactor`` (:obj:`float`, optional): A list of floats giving the scaling
+            for the ordinate values.  Defaults to 1.
+
+            ``rcParams``` (:obj:`dict`, optional): A dictionary of
+            :obj:`matplotlib.rcParams` to be applied to the plot.
+            Defaults to the default rcParams.
+
+            ``plotParams`` (:obj:`list`, optional): A list of
+            dictionaries of valid :obj:`matplotlib.pyplot.plot` optional
+            keyword arguments to be applied to the plot.  The list must
+            have the same number of elements as ``species``.
+
+            ``**kwargs``:  Acceptable :obj:`matplotlib.pyplot` functions.
+            Include directly, as a :obj:`dict`, or both.
+
+        Returns:
+            A matplotlib plot.
+
+        """
+
+        self.set_plot_params(mpl, rcParams)
+
+        if yfactor:
+            if len(yfactor) != len(props):
+                print("yfactor length must be the same as the number of y properties.")
+                return
+        else:
+            yfactor = np.full(len(props), 1.0)
+
+        if plotParams:
+            if len(plotParams) != len(props):
+                print(
+                    "Number of plotParam elements must equal" + " number of properties."
+                )
+                return
+
+        x = self.get_group_properties_in_zones_as_floats(group, [prop])[prop]
+        y = self.get_group_properties_in_zones_as_floats(group, props)
+
+        for i, pr in enumerate(props):
+            if plotParams is None:
+                p = {}
+            else:
+                p = plotParams[i]
+            if "label" not in p:
+                p = self._merge_dicts(p, {"label": pr})
+            plt.plot(x / xfactor, y[pr] / yfactor[i], **p)
+
+        if "xlabel" not in kwargs:
+            plt.xlabel(prop)
+
+        if "ylabel" not in kwargs and len(props) == 1:
+            plt.ylabel(props[0])
+
+        if len(props) > 1:
+            plt.legend()
+
+        self.apply_class_methods(plt, kwargs)
+
+        self.show_or_close(plt, kwargs)
+
     def plot_zone_mass_fractions_vs_property(
         self,
         zone,
@@ -842,3 +932,153 @@ class H5(wnb.Base):
             anim.save(movie_name, fps=fps)
 
         return anim
+
+
+class New_H5(wnb.Base):
+    """A class for creating webnucleo hdf5 files.
+
+       Each instance corresponds to new hdf5.  Main method sets group data.
+
+       Args:
+           ``file`` (:obj:`str`): A string giving the name of the new h5py\
+            `file <https://docs.h5py.org/en/stable/high/file.html>`_.
+
+           ``nucs`` (:obj:`dict`): A dictionary of nuclide data.
+
+       """
+
+    def __init__(self, file, nucs):
+        self.file = h5py.File(file, "w")
+        self.nucs = nucs
+        self._add_nuclide_data(nucs)
+        self.nuc_dict = {}
+
+        i = 0
+        for nuc in self.nucs:
+            self.nuc_dict[nuc] = i
+            i += 1
+
+    def __del__(self):
+        self.file.close()
+
+    def _add_nuclide_data(self, nucs):
+        dt = h5py.string_dtype()
+
+        my_type = [
+            ("Name", dt),
+            ("index", "int"),
+            ("Z", "int"),
+            ("A", "int"),
+            ("State", dt),
+            ("Source", dt),
+            ("Mass Excess", "float"),
+            ("Spin", "float"),
+        ]
+
+        my_data = np.array([], dtype=my_type)
+
+        i = 0
+        for nuc in nucs:
+            my_nuc = nucs[nuc]
+            my_data = np.append(
+                my_data,
+                np.array(
+                    (
+                        nuc,
+                        i,
+                        my_nuc["z"],
+                        my_nuc["a"],
+                        my_nuc["state"],
+                        my_nuc["source"],
+                        my_nuc["mass excess"],
+                        my_nuc["spin"],
+                    ),
+                    dtype=my_type,
+                ),
+            )
+            i += 1
+
+        self.file.create_dataset("Nuclide Data", data=my_data)
+
+    def _add_zone_labels_to_group(self, g, zones):
+
+        dt = h5py.string_dtype()
+
+        my_type = [("Label 1", dt), ("Label 2", dt), ("Label 3", dt)]
+
+        my_data = np.array([], dtype=my_type)
+
+        for zone in zones:
+            if type(zone) is tuple:
+                tup = zone
+            else:
+                tup = (zone, "0", "0")
+            my_data = np.append(
+                my_data, np.array((tup[0], tup[1], tup[2]), dtype=my_type)
+            )
+
+        g.create_dataset("Zone Labels", data=my_data)
+
+    def _add_zone_properties_to_group(self, g, zones):
+        gp = g.create_group("Zone Properties")
+
+        dt = h5py.string_dtype()
+
+        my_type = [("Name", dt), ("Tag 1", dt), ("Tag 2", dt), ("Value", dt)]
+
+        i = 0
+        for zone in zones:
+            my_data = np.array([], dtype=my_type)
+            props = zones[zone]["properties"]
+            for prop in props:
+                name = str(prop[0])
+                tag1 = "0"
+                tag2 = "0"
+                value = str(props[prop])
+                if type(prop) is tuple:
+                    name = str(prop[0])
+                    tag1 = str(prop[1])
+                    if len(prop) == 3:
+                        tag2 = str(prop[2])
+                else:
+                    name = str(prop)
+                my_data = np.append(
+                    my_data, np.array((name, tag1, tag2, value), dtype=my_type)
+                )
+            gp.create_dataset(str(i), data=my_data, dtype=my_type)
+            i += 1
+
+    def _add_zone_mass_fractions_to_group(self, g, zones):
+        dt = h5py.string_dtype()
+
+        my_data = np.zeros((len(zones), len(self.nucs)), dtype=float)
+
+        i = 0
+        for zone in zones:
+            mass_fracs = zones[zone]["mass fractions"]
+            for key in mass_fracs:
+                my_data[i][self.nuc_dict[key[0]]] = mass_fracs[key]
+            i += 1
+
+        g.create_dataset("Mass Fractions", data=my_data)
+
+    def add_group(self, group, zones):
+        """Method to add a group to an hdf5 file.
+
+        Args:
+
+            ``group`` (:obj:`str`): A string giving the group name.
+
+            ``zones`` (:obj:`dict`): A dictionary of zone data for the group.
+
+        Returns:
+            On successful return, the group has been added to the
+            hdf5 file.
+
+        """
+
+        g = self.file.create_group(group)
+
+        self._add_zone_labels_to_group(g, zones)
+        self._add_zone_properties_to_group(g, zones)
+        self._add_zone_mass_fractions_to_group(g, zones)
