@@ -1,3 +1,4 @@
+import os
 import wnutils.base as wb
 import matplotlib as mpl
 import matplotlib.pyplot as plt
@@ -10,13 +11,13 @@ from scipy.interpolate import interp1d
 
 
 class Reaction(wb.Base):
-    """A class for storing and retrieving data about reactions.
-
-       """
+    """A class for storing and retrieving data about reactions."""
 
     def __init__(self):
         self.reactants = []
+        self.nuclide_reactants = []
         self.products = []
+        self.nuclide_products = []
         self.source = ""
         self.data = {}
 
@@ -151,10 +152,14 @@ class Reaction(wb.Base):
         reactants = reaction_node.xpath("reactant")
         for reactant in reactants:
             self.reactants.append(reactant.text)
+            if not self.is_non_nuclide_reaction_element_string(reactant.text):
+                self.nuclide_reactants.append(reactant.text)
 
         products = reaction_node.xpath("product")
         for product in products:
             self.products.append(product.text)
+            if not self.is_non_nuclide_reaction_element_string(product.text):
+                self.nuclide_products.append(product.text)
 
         self.data = self._get_reaction_data(reaction_node)
 
@@ -310,13 +315,13 @@ class Reaction(wb.Base):
 class Xml(wb.Base):
     """A class for reading and plotting webnucleo xml files.
 
-       Each instance corresponds to an xml file.  Methods extract
-       data and plot data from the file.
+    Each instance corresponds to an xml file.  Methods extract
+    data and plot data from the file.
 
-       Args:
-           ``file`` (:obj:`str`): The name of the xml file.
+    Args:
+        ``file`` (:obj:`str`): The name of the xml file.
 
-       """
+    """
 
     def __init__(self, file):
         parser = etree.XMLParser(remove_blank_text=True)
@@ -629,7 +634,7 @@ class Xml(wb.Base):
 
         Args:
             ``zone_xpath`` (:obj:`str`): XPath expression to select
-            zone.  Must be evaluate to a single zone.
+            zone.  Must evaluate to a single zone.
 
         Returns:
             :obj:`dict`: A dictionary containing all the properties in
@@ -1447,17 +1452,19 @@ class Xml(wb.Base):
 
         """
 
-        url_prefix = "http://libnucnet.sourceforge.net/xsd_pub/2019-01-15/"
-
         xsd_dict = {
-            "nuclear_data": url_prefix + "libnucnet__nuc.xsd",
-            "reaction_data": url_prefix + "libnucnet__reac.xsd",
-            "nuclear_network": url_prefix + "libnucnet__net.xsd",
-            "zone_data": url_prefix + "zone_data.xsd",
-            "libnucnet_input": url_prefix + "libnucnet.xsd",
+            "nuclear_data": "libnucnet__nuc.xsd",
+            "reaction_data": "libnucnet__reac.xsd",
+            "nuclear_network": "libnucnet__net.xsd",
+            "zone_data": "zone_data.xsd",
+            "libnucnet_input": "libnucnet.xsd",
         }
 
-        xml_validator = etree.XMLSchema(file=xsd_dict[self._root.tag])
+        schema_file = os.path.join(
+            os.path.dirname(__file__), "xsd_pub", xsd_dict[self._root.tag]
+        )
+
+        xml_validator = etree.XMLSchema(file=schema_file)
         xml_validator.assert_(self._xml)
 
     def get_zone_data(self, zone_xpath=""):
@@ -1500,15 +1507,15 @@ class Xml(wb.Base):
 class New_Xml(wb.Base):
     """A class for creating webnucleo xml files.
 
-       Each instance corresponds to new xml.  Methods set
-       the nuclide, reaction, or zone data or write the xml to a file.
+    Each instance corresponds to new xml.  Methods set
+    the nuclide, reaction, or zone data or write the xml to a file.
 
-       Args:
-           ``xml_type`` (:obj:`str`, optional): The type of xml file to
-           be created ("nuclear_data", "reaction_data", "nuclear_network",
-           "zone_data", or "libnucnet_input").  Defaults to "nuclear_network".
+    Args:
+        ``xml_type`` (:obj:`str`, optional): The type of xml file to
+        be created ("nuclear_data", "reaction_data", "nuclear_network",
+        "zone_data", or "libnucnet_input").  Defaults to "nuclear_network".
 
-       """
+    """
 
     def __init__(self, xml_type="nuclear_network"):
         if xml_type not in [
@@ -1740,7 +1747,7 @@ class New_Xml(wb.Base):
             self._set_xml_data_for_zone(new_zone, zones[zone])
 
     def write(self, file, pretty_print=True):
-        """Method to write the xml
+        """Method to write the xml to a file.
 
         Args:
 
